@@ -102,4 +102,4 @@ class IARGenerator(Generator):
     # 获取生成工程的名称
     def project_filepath(self, prj_info, prj_path) -> str:
         filename = 'Project.eww'
-        return os.path.join(prj_path, filename)
+        return os.path.join(prj_path, 'EWARM', filename)
