@@ -81,4 +81,4 @@ class Keil5Generator(Generator):
     # 获取生成工程的名称
     def project_filepath(self, prj_info, prj_path) -> str:
         filename = prj_info['name'] + '.uvprojx'
-        return os.path.join(prj_path, filename)
+        return os.path.join(prj_path, 'MDK-ARM', filename)
